@@ -44,8 +44,9 @@ gsl.bs.default <- function(x,
 			or <- x > x.max 
 	}
 
-  ## we should check Xs  are within knots   
-## It seems that 'knots' is given,  we don't require x.min and x.max,  otherwise,  we check the boundary.
+  ## We check whether the Xs are within knots. It seems that if 'knots'
+  ## is given, we don't require x.min and x.max, otherwise, we check
+  ## the boundary.
 
 	if(!is.null(knots)) {
 			ol <- ol | x < min(knots)
@@ -72,7 +73,7 @@ gsl.bs.default <- function(x,
 					else {
 							xl <- cbind(1, outer(x[ol]-k.pivot, 1L:(degree-deriv),  "^"))
 					}
-					tt <- bs.des(rep(k.pivot, ord-deriv), degree, nbreak, deriv=derivs, x.min, x.max, knots)  #If 'knots' is given,  we have not implemented it.
+					tt <- bs.des(rep(k.pivot, ord-deriv), degree, nbreak, deriv=derivs, x.min, x.max, knots)  
 					B[ol, ] <- xl %*% (tt/scalef)
 			}
 			if(any(or) && (ord>deriv)){
