@@ -1,44 +1,46 @@
-/*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
-/*                                                                                     */
-/*                                                                                     */
-/*  NOMAD - version 3.8.0 has been created by                                          */
-/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
-/*                                                                                     */
-/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
-/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
-/*  and were funded by AFOSR and Exxon Mobil.                                          */
-/*                                                                                     */
-/*                                                                                     */
-/*  Contact information:                                                               */
-/*    Ecole Polytechnique de Montreal - GERAD                                          */
-/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada                  */
-/*    e-mail: nomad@gerad.ca                                                           */
-/*    phone : 1-514-340-6053 #6928                                                     */
-/*    fax   : 1-514-340-5665                                                           */
-/*                                                                                     */
-/*  This program is free software: you can redistribute it and/or modify it under the  */
-/*  terms of the GNU Lesser General Public License as published by the Free Software   */
-/*  Foundation, either version 3 of the License, or (at your option) any later         */
-/*  version.                                                                           */
-/*                                                                                     */
-/*  This program is distributed in the hope that it will be useful, but WITHOUT ANY    */
-/*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A    */
-/*  PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.   */
-/*                                                                                     */
-/*  You should have received a copy of the GNU Lesser General Public License along     */
-/*  with this program. If not, see <http://www.gnu.org/licenses/>.                     */
-/*                                                                                     */
-/*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
-/*-------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------*/
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search -                */
+/*                                                                                 */
+/*  NOMAD - version 3.9.1 has been created by                                      */
+/*                 Charles Audet               - Ecole Polytechnique de Montreal   */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  The copyright of NOMAD - version 3.9.1 is owned by                             */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                             */
+/*                                                                                 */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created     */
+/*  and developed by Mark Abramson, Charles Audet, Gilles Couture, and John E.     */
+/*  Dennis Jr., and were funded by AFOSR and Exxon Mobil.                          */
+/*                                                                                 */
+/*  Contact information:                                                           */
+/*    Ecole Polytechnique de Montreal - GERAD                                      */
+/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada              */
+/*    e-mail: nomad@gerad.ca                                                       */
+/*    phone : 1-514-340-6053 #6928                                                 */
+/*    fax   : 1-514-340-5665                                                       */
+/*                                                                                 */
+/*  This program is free software: you can redistribute it and/or modify it        */
+/*  under the terms of the GNU Lesser General Public License as published by       */
+/*  the Free Software Foundation, either version 3 of the License, or (at your     */
+/*  option) any later version.                                                     */
+/*                                                                                 */
+/*  This program is distributed in the hope that it will be useful, but WITHOUT    */
+/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or          */
+/*  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License    */
+/*  for more details.                                                              */
+/*                                                                                 */
+/*  You should have received a copy of the GNU Lesser General Public License       */
+/*  along with this program. If not, see <http://www.gnu.org/licenses/>.           */
+/*                                                                                 */
+/*  You can find information on the NOMAD software at www.gerad.ca/nomad           */
+/*---------------------------------------------------------------------------------*/
+
 /**
  \file   Directions.hpp
  \brief  Set of polling directions (headers)
@@ -70,10 +72,13 @@ namespace NOMAD {
         /// Types of the secondary poll directions.
         std::set<NOMAD::direction_type> _sec_poll_dir_types;
         
+        /// Types of the intensification poll directions.
+        std::set<NOMAD::direction_type> _int_poll_dir_types;
+        
         bool _is_binary;      ///< Flag equal to \c true if all variables are binary.
         bool _is_categorical; ///< Flag equal to \c true if all variables are categorical.
         
-        bool _is_orthomads;  //< Flag equal to \c true if Ortho-MADS directions are used.
+        bool _is_orthomads;  ///< Flag equal to \c true if Ortho-MADS directions are used.
         
         // LT-MADS attributes:
         NOMAD::Direction * _bl [1+2*NOMAD::L_LIMITS];  ///< Directions b(ell) (LT-MADS).
@@ -179,11 +184,13 @@ namespace NOMAD {
          \param nc                 Number of non-fixed variables          -- \b IN.
          \param direction_types    Types of the poll directions           -- \b IN.
          \param sec_poll_dir_types Types of the secondary poll directions -- \b IN.
+        \param int_poll_dir_types  Types of the intensification poll directions -- \b IN.
          \param out                The display                            -- \b IN.
          */
         Directions ( int                                     nc                 ,
                     const std::set<NOMAD::direction_type> & direction_types    ,
                     const std::set<NOMAD::direction_type> & sec_poll_dir_types ,
+                    const std::set<NOMAD::direction_type> & int_poll_dir_types ,
                     const NOMAD::Display                  & out                  );
         
         /// Copy constructor.
@@ -194,6 +201,7 @@ namespace NOMAD {
         : _nc                 ( d._nc                 ) ,
         _direction_types    ( d._direction_types    ) ,
         _sec_poll_dir_types ( d._sec_poll_dir_types ) ,
+        _int_poll_dir_types ( d._int_poll_dir_types ) ,
         _is_binary          ( d._is_binary          ) ,
         _is_categorical     ( d._is_categorical     ) ,
         _is_orthomads       ( d._is_orthomads       ) ,
@@ -211,14 +219,14 @@ namespace NOMAD {
          */
         void compute ( std::list<NOMAD::Direction> & dirs           ,
                       NOMAD::poll_type               poll           ,
-                      const NOMAD::OrthogonalMesh  & mesh			);
+                      const NOMAD::OrthogonalMesh  & mesh           );
         
         /// Compute a random direction on a N-Sphere.
         /**
-         \param random_dir								-- \b OUT.
+         \param random_dir                              -- \b OUT.
          \return A boolean equal to \c true if the computation went well.
          */
-        bool compute_dir_on_unit_sphere (	NOMAD::Direction	& random_dir ) const;
+        bool compute_dir_on_unit_sphere ( NOMAD::Direction & random_dir ) const;
         
         
         /// Check if Ortho-MADS directions are used.
@@ -257,6 +265,16 @@ namespace NOMAD {
             return _sec_poll_dir_types;
         }
         
+        
+        /// Access to the intensification poll direction types.
+        /**
+         \return Intensification poll direction types.
+         */
+        const std::set<NOMAD::direction_type> & get_int_poll_dir_types ( void ) const
+        {
+            return _int_poll_dir_types;
+        }
+        
         /// Reset directions for binary variables.
         void set_binary ( void );
         
