@@ -1,6 +1,6 @@
 /*-------------------------------------------------------------------------------------*/
 /*  sgtelib - A surrogate model library for derivative-free optimization               */
-/*  Version 2.0.1                                                                      */
+/*  Version 2.0.2                                                                      */
 /*                                                                                     */
 /*  Copyright (C) 2012-2017  Sebastien Le Digabel - Ecole Polytechnique, Montreal      */ 
 /*                           Bastien Talgorn - McGill University, Montreal             */
@@ -25,9 +25,11 @@
 
 #include "Surrogate_Parameters.hpp"
 using namespace SGTELIB;
-/*----------------------------*/
-/*         constructor        */
-/*----------------------------*/
+/*---------------------------------------------------------------*/
+/*         constructor                                           */
+/* Use a model_type to define the model, then use default values */
+/* associated to this specific model_type.                       */
+/*---------------------------------------------------------------*/
 SGTELIB::Surrogate_Parameters::Surrogate_Parameters ( const model_t mt ):
   _type  ( mt ){
   set_defaults();
@@ -35,9 +37,11 @@ SGTELIB::Surrogate_Parameters::Surrogate_Parameters ( const model_t mt ):
 }//
 
 
-/*----------------------------*/
-/*          constructor       */
-/*----------------------------*/
+/*-----------------------------------------------------------------------*/
+/*          constructor                                                  */
+/* Use a string provided by the user. Read the model_type in the string, */
+/* then parse the string to read all the other parameters.               */
+/*-----------------------------------------------------------------------*/
 SGTELIB::Surrogate_Parameters::Surrogate_Parameters ( const std::string & s ):
   _type  ( read_model_type(s) ){
   set_defaults();
@@ -91,20 +95,28 @@ std::string SGTELIB::Surrogate_Parameters::to_standard_field_name (const std::st
   if ( streqi(field,"WEIGHT_CHOICE") )  return "WEIGHT_TYPE";
   if ( streqi(field,"CHOICE_WEIGHT") )  return "WEIGHT_TYPE";
 
-  if ( streqi(field,"RIDGE") )          return "RIDGE";
-  if ( streqi(field,"RIDGE_COEF") )     return "RIDGE";
-  if ( streqi(field,"RIDGE_PARAM") )    return "RIDGE";
+  if ( streqi(field,"RIDGE") )                return "RIDGE";
+  if ( streqi(field,"RIDGE_COEF") )           return "RIDGE";
+  if ( streqi(field,"RIDGE_PARAM") )          return "RIDGE";
+  if ( streqi(field,"RIDGE_COEFFICIENT") )    return "RIDGE";
+  if ( streqi(field,"RIDGE_PARAMETER") )      return "RIDGE";
+  if ( streqi(field,"REGULARIZATION_PARAM") ) return "RIDGE";
+  if ( streqi(field,"REGULARIZATION_COEF") )  return "RIDGE";
 
   if ( streqi(field,"KERNEL_TYPE") )    return "KERNEL_TYPE";
   if ( streqi(field,"TYPE_KERNEL") )    return "KERNEL_TYPE";
   if ( streqi(field,"KERNEL") )         return "KERNEL_TYPE";
 
-  if ( streqi(field,"KERNEL_COEF") )    return "KERNEL_COEF";
-  if ( streqi(field,"COEF_KERNEL") )    return "KERNEL_COEF";
-  if ( streqi(field,"KERNEL_SHAPE") )   return "KERNEL_COEF";
-  if ( streqi(field,"COEF_SHAPE") )     return "KERNEL_COEF";
-  if ( streqi(field,"SHAPE") )          return "KERNEL_COEF";
-  if ( streqi(field,"SHAPE_COEF") )     return "KERNEL_COEF";
+  if ( streqi(field,"KERNEL_COEF") )         return "KERNEL_COEF";
+  if ( streqi(field,"KERNEL_COEFFICIENT") )  return "KERNEL_COEF";
+  if ( streqi(field,"COEF_KERNEL") )         return "KERNEL_COEF";
+  if ( streqi(field,"KERNEL_SHAPE") )        return "KERNEL_COEF";
+  if ( streqi(field,"COEF_SHAPE") )          return "KERNEL_COEF";
+  if ( streqi(field,"COEFFICIENT_SHAPE") )   return "KERNEL_COEF";
+  if ( streqi(field,"SHAPE") )               return "KERNEL_COEF";
+  if ( streqi(field,"SHAPE_COEF") )          return "KERNEL_COEF";
+  if ( streqi(field,"SHAPE_COEFFICIENT") )   return "KERNEL_COEF";
+
 
   if ( streqi(field,"METRIC") )         return "METRIC_TYPE";
   if ( streqi(field,"METRIC_TYPE") )    return "METRIC_TYPE";
@@ -140,43 +152,47 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
   std::string content;
   bool content_is_optim;
   std::istringstream in_line (model_description);	
-  #ifdef SGTELIB_DEBUG
+  const bool display = false;
+  if (display){
     SGTELIB::rout << "Model description: " << model_description << "\n";
-  #endif
+  }
   while ( in_line >> field ){
 
-    #ifdef SGTELIB_DEBUG
+    if (display){
       SGTELIB::rout << "FIELD: " << field ;
-    #endif
+    }
     // Convert the field name into a std field name
     field = to_standard_field_name(field);
-    #ifdef SGTELIB_DEBUG
+    if (display){
       SGTELIB::rout << " (" << field << ")\n";
-    #endif   
+    }   
     // Check if this field is authorized for this type of model.
-    if ( !  authorized_field(field)){
+    if ( ! authorized_field(field) ){
       SGTELIB::rout << "model_description: " << model_description << "\n";
       throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Unauthorized field \""+field+"\" in a model of type "+model_type_to_str(_type) );
     }
-    #ifdef SGTELIB_DEBUG
+    if (display){
       SGTELIB::rout << "CONTENT: " << content << "\n";
-    #endif
+    }
     // Read the content 
-    if ( !  (in_line >> content))
+    if ( !(in_line >> content) )
       throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Missing content for field \""+field+"\"" );
 
-
-
     // Detect if the content is "OPTIM".
     content_is_optim = ( streqi(content,"OPTIM") || streqi(content,"OPTIMIZATION") || streqi(content,"OPTIMIZE") );
+    if (display){
+      SGTELIB::rout << "CONTENT IS OPTIM: " << content_is_optim << "\n";
+    }
 
     // Check if optimization is allowed for this field.
-    if ((content_is_optim) && ( !  authorized_optim(field))) {
+    if ((content_is_optim) && (!authorized_optim(field))) {
       SGTELIB::rout << "model_description: " << model_description << "\n";
       throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Field \""+field+"\" cannot be optimized." );
     }
 
     if (streqi(field,"TYPE")){
+      // If the field is "TYPE", then check that the model_type is consistent with the
+      // one already detected.
       if ( str_to_model_type(content) != _type ){
         SGTELIB::rout << "model_description: " << model_description << "\n";
         throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Unconsistent model type!" );
@@ -184,6 +200,7 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
     }
     else if (streqi(field,"DEGREE")){
       if (content_is_optim)
+        // _degree = default value.
         _degree_status = SGTELIB::STATUS_OPTIM;
       else{
         _degree = SGTELIB::stoi(content);
@@ -192,7 +209,8 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
     }
     else if (streqi(field,"KERNEL_TYPE")){
       if (content_is_optim)
-         _kernel_type_status = SGTELIB::STATUS_OPTIM;
+        // _kernel_type = default value        
+        _kernel_type_status = SGTELIB::STATUS_OPTIM;
       else{
         _kernel_type = SGTELIB::str_to_kernel_type(content);
         _kernel_type_status = SGTELIB::STATUS_FIXED;
@@ -200,6 +218,7 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
     }
     else if ( streqi(field,"KERNEL_COEF") ){
       if (content_is_optim)
+        // _kernel_coef = default value
         _kernel_coef_status = SGTELIB::STATUS_OPTIM;
       else{
         _kernel_coef = SGTELIB::stod(content);
@@ -208,7 +227,8 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
     }
     else if (streqi(field,"RIDGE")){
       if (content_is_optim)
-         _ridge_status = SGTELIB::STATUS_OPTIM;
+        // _ridge = default value
+        _ridge_status = SGTELIB::STATUS_OPTIM;
       else{
         _ridge = SGTELIB::stod(content);
         _ridge_status = SGTELIB::STATUS_FIXED;
@@ -216,6 +236,7 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
     }
     else if ( streqi(field,"DISTANCE_TYPE") ){
       if (content_is_optim)
+        // _distance_type = default value
         _distance_type_status = SGTELIB::STATUS_OPTIM;
       else{
         _distance_type = str_to_distance_type(content);
@@ -226,18 +247,31 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
       _weight_type = str_to_weight_type(content);
       if (content_is_optim) 
         _weight_status = SGTELIB::STATUS_OPTIM;
+      // Note, the weight_type can be one of the following:
+      // - WTA1
+      // - WTA3
+      // - SELECT
+      // - OPTIM
+      // If the weight_type is OPTIM, then weight_status is OPTIM.
+      // The variable weight_type is not optimized. It is the weights that are
+      // optimized.
+      // This is different from, for example, the kernel_type, which can be optimized.
     }
     else if ( streqi(field,"METRIC_TYPE") ){
       _metric_type = str_to_metric_type(content);
+      // Cannot be optimized
     }
     else if ( streqi(field,"BUDGET") ){
       _budget = SGTELIB::stoi(content);
+      // Cannot be optimized
     }
     else if ( streqi(field,"PRESET") ){
       _preset = content;
+      // Cannot be optimized
     }
     else if ( streqi(field,"OUTPUT") ){
       _output = content;
+      // Cannot be optimized
     }
     else{
       SGTELIB::rout << "model_description: " << model_description << "\n";
@@ -247,7 +281,10 @@ void SGTELIB::Surrogate_Parameters::read_string (const std::string & model_descr
 }//
 
 
-
+/*----------------------------------------------------------*/
+/* Indicate if the field name given in input is authorized  */
+/* for the current type of model                            */
+/*----------------------------------------------------------*/
 bool SGTELIB::Surrogate_Parameters::authorized_field ( const std::string & field ) const{
 
   if (streqi(field,"TYPE")) return true;
@@ -259,7 +296,7 @@ bool SGTELIB::Surrogate_Parameters::authorized_field ( const std::string & field
     case SGTELIB::LINEAR:
     case SGTELIB::TGP: 
     case SGTELIB::SVN: 
-      throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Not implemented yetnot " );
+      throw SGTELIB::Exception ( __FILE__ , __LINE__ , "Not implemented yet! " );
 
     case SGTELIB::CN:
       if (streqi(field,"DISTANCE_TYPE")) return true;
@@ -268,6 +305,7 @@ bool SGTELIB::Surrogate_Parameters::authorized_field ( const std::string & field
     case SGTELIB::KRIGING: 
       if (streqi(field,"RIDGE"))         return true;
       if (streqi(field,"DISTANCE_TYPE")) return true;
+      break;
 
     case SGTELIB::PRS: 
     case SGTELIB::PRS_EDGE: 
@@ -314,6 +352,10 @@ bool SGTELIB::Surrogate_Parameters::authorized_field ( const std::string & field
   return false;
 }//
 
+
+/*----------------------------------------------------------*/
+/* Indicate if the field given in input can be optimized    */
+/*----------------------------------------------------------*/
 bool SGTELIB::Surrogate_Parameters::authorized_optim ( const std::string & field ) {
 
   if (streqi(field,"DEGREE"))        return true;
@@ -337,9 +379,10 @@ bool SGTELIB::Surrogate_Parameters::authorized_optim ( const std::string & field
 
 
 
-/*----------------------------*/
-/*          Check             */
-/*----------------------------*/
+/*-------------------------------------------------*/
+/*          Check                                  */
+/* Verify the consistency of the set of parameters */
+/*-------------------------------------------------*/
 void SGTELIB::Surrogate_Parameters::check ( void ) {
   switch (_type) {
     case SGTELIB::LINEAR:
@@ -375,8 +418,11 @@ void SGTELIB::Surrogate_Parameters::check ( void ) {
         throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"kernel_coef must be > 0" );
       if (_ridge<0)
         throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"ridge must be >= 0" );
-      if ( ( !  kernel_has_parameter(_kernel_type)) && (_kernel_type_status==SGTELIB::STATUS_FIXED) ){
-        // If the kernel coef is not used in this type of kernel, then it should be fixed. 
+      if ( ( ! kernel_has_parameter(_kernel_type)) && (_kernel_type_status==SGTELIB::STATUS_FIXED) ){
+        // If the kernel_type is fixed by the user, and this type of kernel does not
+        // require a kernel_coefficient, then the kernel_coefficient is arbitrarily set to 1 
+        // and its status is set to "fixed". See the class Kernel to see which kernel type requires
+        // a coefficient or not.
         _kernel_coef = 1;
         _kernel_coef_status = SGTELIB::STATUS_FIXED;
       }
@@ -387,6 +433,18 @@ void SGTELIB::Surrogate_Parameters::check ( void ) {
         throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"degree for LOWESS model must be 0, 1 or 2" );
       if (_ridge<0)
         throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"ridge must be >= 0" );
+      // The default preset for LOWESS models is DGN. 
+      // The preset defines how the weight of each data point is computed.
+      // D : w_i = phi(distance_i), where distance_i is the distance between the prediction point 
+      //           and the data point x_i.
+      // DEN : w_i = phi(distance_i/dq_i), where dq_i is the distance between the prediction point
+      //             and the q^th closest data point, and dq_i is computed with empirical method.
+      // DGN : w_i = phi(distance_i/dq_i), where dq_i is computed with gamma method.
+      // RE : w_i = phi(rank_i), where rank_i is the rank of x_i in terms of distance 
+      //            to the prediction point, and the rank_i is computed with empirical method.
+      // RG : w_i = phi(rank_i), where the rank is computed with gamma method.
+      // REN : w_i = same as RE but the ranks are normalized in [0,1]
+      // RGN : w_i = same as RG but the ranks are normalized in [0,1]
       if ( (_preset!="D"  ) &&
            (_preset!="DEN") &&
            (_preset!="DGN") &&
@@ -413,8 +471,6 @@ void SGTELIB::Surrogate_Parameters::check ( void ) {
   }
 
 
-
-
   // Count the number of parameters to optimize
   _nb_parameter_optimization = 0;
   if (_degree_status==SGTELIB::STATUS_OPTIM)           _nb_parameter_optimization++;
@@ -744,9 +800,11 @@ std::string SGTELIB::Surrogate_Parameters::get_short_string ( void ) const {
 
 
 
-/*------------------------------------*/
-/*  Parameter domains and definitions */
-/*------------------------------------*/
+/*------------------------------------------------------------*/
+/*  get_x                                                     */
+/* Creates a vector that contains the numerical values of all */
+/* all the parameters that must be optmized.                  */
+/*------------------------------------------------------------*/
 SGTELIB::Matrix SGTELIB::Surrogate_Parameters::get_x ( void ){
 
     SGTELIB::Matrix X ("X",1,_nb_parameter_optimization);
@@ -818,15 +876,17 @@ void SGTELIB::Surrogate_Parameters::set_x ( const SGTELIB::Matrix X ){
 
 }//
 
-/*------------------------------------*/
-/*  Parameter domains and definitions */
-/*------------------------------------*/
+/*------------------------------------------------------------------------------------*/
+/*  Parameter domains and definitions                                                 */
+/* Defines the bounds, domain and log-scale for each parameter that must be optimized */
+/*------------------------------------------------------------------------------------*/
 void SGTELIB::Surrogate_Parameters::get_x_bounds ( SGTELIB::Matrix * LB ,
                                                    SGTELIB::Matrix * UB ,
                                                    SGTELIB::param_domain_t * domain,
                                                    bool * logscale ){
 
-    if ( ( ! LB) || ( ! UB) || ( ! domain) || ( ! logscale) ){
+    // Check that the arrays or matrices are initialized.
+    if ( (!LB) || (!UB) || (!domain) || (!logscale) ){
       SGTELIB::rout << LB << " " << UB << " " << domain << " " << logscale << "\n";
       throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Pointers are NULL." );
     }
@@ -921,6 +981,8 @@ void SGTELIB::Surrogate_Parameters::get_x_bounds ( SGTELIB::Matrix * LB ,
       SGTELIB::rout << "N=" << N << "\n";
       throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Unconcistency in the value of k." );
     }
+
+
     // ----- CHECK CONSISTENCY -------
     bool error = false;
     for (j=0 ; j<N ; j++){
@@ -946,7 +1008,7 @@ void SGTELIB::Surrogate_Parameters::get_x_bounds ( SGTELIB::Matrix * LB ,
         }
       }
 
-      // Check fo reach domain type
+      // Check domain types
       switch (domain[j]){
         case SGTELIB::PARAM_DOMAIN_CONTINUOUS:
           break;
@@ -1070,7 +1132,7 @@ bool SGTELIB::Surrogate_Parameters::check_x ( void ){
 
 
 /*------------------------------------*/
-/*  Parameter domains and definitions */
+/*  Display the parameters            */
 /*------------------------------------*/
 void SGTELIB::Surrogate_Parameters::display_x ( std::ostream & out ){
     out << "Parameter set {\n";
@@ -1110,7 +1172,7 @@ void SGTELIB::Surrogate_Parameters::display_x ( std::ostream & out ){
 
 
 /*----------------------------------------------*/
-/*  smoothness penalty for a set of parameters  */
+/*  Smoothness penalty for a set of parameters  */
 /*----------------------------------------------*/
 double SGTELIB::Surrogate_Parameters::get_x_penalty ( void ){
   double pen = 0;
@@ -1162,12 +1224,24 @@ double SGTELIB::Surrogate_Parameters::get_x_penalty ( void ){
 
 
 
+
 /*-------------------------------------------------*/
 /*  update the dimension of _covariance_parameter  */
 /*  for Kriging models                             */
 /*-------------------------------------------------*/
+// The matrix containing the covariance coefficients, for Kriging models, 
+// is initialized with 2 components (factor and exponent). 
+// In sgtelib 2.0.1, the factor and exponent are the same for all input variables.
+// However, it would be possible to use a different value of factor and exponent
+// for each variable (which is the case in most Kriging implementation).
+// The problem is that the Surrogate_Parameters class is built before the model itself,
+// and the instance Surrogate_Parameters is not able to retrieve the dimension of
+// the input space from either the training set or the model. The following method allows
+// the model to tell to the Surrogate_Parameters what must be the dimension of
+// the set of covariance coefficients. 
+// This function is not used for now, but might be used in future versions of sgtelib.
 void SGTELIB::Surrogate_Parameters::update_covariance_coef ( const int v ){
-
+  // The input value v must be equal to 1 or to the number of variables.
   // Check the old dimension
   const int v0 = _covariance_coef.get_nb_cols()/2;
   if (v<v0) throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"v < v0" );
@@ -1177,8 +1251,8 @@ void SGTELIB::Surrogate_Parameters::update_covariance_coef ( const int v ){
   double factor_mean = 0;
   double exponent_mean = 0;
 
-  // First component is the noise. Then the exponent and factor for each dimension.
-  int k = 1;
+  //  Compute the mean value for exponent and factor.
+  int k = 0;
   for (int i=0 ; i<v0 ; i++){
     exponent_mean += _covariance_coef[k++];
     factor_mean   += _covariance_coef[k++];
@@ -1198,24 +1272,3 @@ void SGTELIB::Surrogate_Parameters::update_covariance_coef ( const int v ){
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
